pilot.api.compute.api.PilotCompute

Package pilot :: Package api :: Package compute :: Module api :: Class PilotCompute |

# Class PilotCompute

source code

PilotCompute (PC).

This is the object that is returned by the PilotComputeService when a new PilotCompute (aka Pilot-Job) is created based on a PilotComputeDescription.

The PilotCompute object can be used by the application to keep track of PilotComputes that are active.

A PilotCompute has state, can be queried, can be cancelled and be re-initialized.

Instance Methods
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
cancel(self) Remove the PilotCompute from the PilotCompute Service. | source code
get_state(self) | source code
reinitialize(self, pilotjob_description) Re-Initialize the PilotCompute to the (new) PilotComputeDescription. | source code
set_callback(self, member, cb) Set a callback function for a member. | source code
unset_callback(self, member) Unset a callback function from a member | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
| callback
| context
| description
| id
| pj_type
| rm
| state
| state_detail
| wall_time_left
Inherited from `object`: `__class__`

Method Details

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### cancel(self) | source code
Remove the PilotCompute from the PilotCompute Service. Keyword arguments: None

### reinitialize(self, pilotjob_description) | source code
Re-Initialize the PilotCompute to the (new) PilotComputeDescription. Keyword arguments: pilotjob_description -- A PilotComputeDescription

### set_callback(self, member, cb) | source code
Set a callback function for a member. Keyword arguments: member -- The member to set the callback for (state / state_detail). cb -- The callback object to call.

### unset_callback(self, member) | source code
Unset a callback function from a member Keyword arguments: member -- The member to unset the callback from.